@@ -263,12 +263,9 @@ where
         if cfg!(feature = "debug") {
             tracing::trace!("inline: inline_vars_in_node");
         }
-        let ctx = Ctx {
-            inline_prevented: false,
-            ..self.ctx
-        };
+
         let orig_vars = replace(&mut self.state.vars_for_inlining, vars);
-        n.visit_mut_with(&mut *self.with_ctx(ctx));
+        n.visit_mut_with(self);
         self.state.vars_for_inlining = orig_vars;
     }
 
@@ -316,7 +313,7 @@ where
             ExprOrSuper::Expr(e) => &mut **e,
         };
 
-        if self.ctx.inline_prevented {
+        if self.ctx.dont_invoke_iife {
             tracing::trace!("iife: [x] Inline is prevented");
             return;
         }
@@ -531,6 +528,14 @@ where
                 ..
             })) => {
                 if decls.iter().any(|decl| match decl.name {
+                    Pat::Ident(BindingIdent {
+                        id:
+                            Ident {
+                                sym: js_word!("arguments"),
+                                ..
+                            },
+                        ..
+                    }) => true,
                     Pat::Ident(..) => false,
                     _ => true,
                 }) {
